@@ -38,7 +38,7 @@ class EBomb:
 
         def __init__(self, max_right_align: int):
             super().__init__()
-            self.maxother = shutil.get_terminal_size().columns - max_right_align
+            self.maxother = max(shutil.get_terminal_size().columns - max_right_align, 6)
 
     def __init__(self, targets: list[str], threads_count: int = None, proxy: bool = True, forever: bool = True,
                  verbose: bool = True):
